@@ -1,21 +1,20 @@
-from skyext import EXT_CONTEXT
-from skyext.intercepter.db_session_intercepter import db_session_decorator
+from skyext import db
+from skyext.base_class.main_base import BaseMain
 from skyext.utils.db_utils import query2dict
 from model1.goods.model import Goods
 
 
-class GoodsManager(object):
+class GoodsManager(BaseMain):
 
-    @db_session_decorator
-    def get_test(self, **params):
+    def get(self, **params):
         if params:
             for i in params:
                 print("find params===>key={0},value={1}".format(i, params[i]))
-        if params and not params.keys().__contains__('id'):
-            raise Exception("find goods, params[id] is not existed")
 
-        session = params.get("db_session")
-        role = session.query(Goods).filter(Goods.id == params.get("id")).one()
+        if not params and params.keys().__contains__('id'):
+            raise Exception("find user, params[id] is not existed")
+
+        role = db.session.query(Goods).filter(Goods.id == params.get("id")).one()
         if role:
             print('type:', type(role))
             print('name:', role.name)
@@ -23,38 +22,22 @@ class GoodsManager(object):
         else:
             return None
 
-    def get(self, **params):
-        if params:
-            for i in params:
-                print("find params===>key={0},value={1}".format(i, params[i]))
-        if not params and params.keys().__contains__('id'):
-            raise Exception("find user, params[id] is not existed")
-
-        with EXT_CONTEXT["db"].session_maker() as session:
-            role = session.query(Goods).filter(Goods.id == params.get("id")).one()
-            if role:
-                print('type:', type(role))
-                print('name:', role.name)
-                return query2dict(role)
-            else:
-                return None
-
-
     def post(self, **params):
         if params:
             for i in params:
                 print("find params===>key={0},value={1}".format(i, params[i]))
 
-        if not params and params.keys().__contains__('id'):
-            raise Exception("find user, params[id] is not existed")
+        if params and not params.keys().__contains__('name'):
+            raise Exception("find user, params[name] is not existed")
 
-        with EXT_CONTEXT["db"].session_maker() as session:
-            list = session.query(Goods).filter(Goods.id == params.get("id")).all()
-            if list:
-                print('type:', type(list))
-                return query2dict(list)
-            else:
-                return None
+        role = Goods(params.get("name"))
+        db.session.add(role)
+        db.session.commit()
+        if role:
+            print('type:', type(role))
+            return query2dict(role)
+        else:
+            return None
 
     def delete(self, **params):
         if params:
@@ -64,13 +47,12 @@ class GoodsManager(object):
         if not params and params.keys().__contains__('id'):
             raise Exception("find user, params[id] is not existed")
 
-        with EXT_CONTEXT["db"].session_maker() as session:
-            _model = session.query(Goods).filter(Goods.id == params.get("id")).first()
-            if _model:
-                session.delete(_model)
-                return query2dict(_model)
-            else:
-                return None
+        _model = db.session.query(Goods).filter(Goods.id == params.get("id")).first()
+        if _model:
+            db.session.delete(_model)
+            return query2dict(_model)
+        else:
+            return None
 
     def put(self, **params):
         if params:
@@ -83,10 +65,10 @@ class GoodsManager(object):
         if not params and params.keys().__contains__('name'):
             raise Exception("find user, params[id] is not existed")
 
-        with EXT_CONTEXT["db"].session_maker() as session:
-            _model = session.query(Goods).filter(Goods.id == params.get("id")).first()
-            if _model:
-                _model.name = params.get("name")
-                return query2dict(_model)
-            else:
-                return None
+        _model = db.session.query(Goods).filter(Goods.id == params.get("id")).first()
+        if _model:
+            _model.name = params.get("name")
+            db.session.commit()
+            return query2dict(_model)
+        else:
+            return None
\ No newline at end of file
