@@ -1,8 +1,8 @@
-from skyext import EXT_CONTEXT
+from skyext.base_class.model_base import BaseModel
 from sqlalchemy import Column, Integer, String
 
 
-class Goods(EXT_CONTEXT["db"].Model if EXT_CONTEXT.get("db") else object):
+class Goods(BaseModel):
 
     __tablename__ = 'goods'
 
