@@ -1,7 +1,8 @@
+from model1.base_action import Model1BaseAction
 from model1.order.main import OrderManager
 
 
-class OrderAction(object):
+class OrderAction(Model1BaseAction):
     def get(self, **params):
         if params:
             for i in params:
