@@ -1,8 +1,8 @@
-from skyext import EXT_CONTEXT
+from skyext.base_class.model_base import BaseModel
 from sqlalchemy import Column, Integer, String
 
 
-class Order(EXT_CONTEXT["db"].Model):
+class Order(BaseModel):
     __tablename__ = 'order'
 
     id = Column(Integer, primary_key=True, autoincrement=True)
